@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2019 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -39,6 +39,7 @@
 #include "config.h"
 #endif
 #include "log.h"
+#include "gkrellm-version.h"
 
 #if !defined(WIN32)
 #include <sys/param.h>
@@ -106,17 +107,6 @@
 
 /* -------------------------------------------------------------------
 */
-#define	GKRELLM_VERSION_MAJOR	2
-#define	GKRELLM_VERSION_MINOR	3
-#define	GKRELLM_VERSION_REV		11
-#define	GKRELLM_EXTRAVERSION	""
-//#define	GKRELLM_EXTRAVERSION	"-pre1"
-
-#define GKRELLM_CHECK_VERSION(major,minor,rev)    \
-	(GKRELLM_VERSION_MAJOR > (major) || \
-	(GKRELLM_VERSION_MAJOR == (major) && GKRELLM_VERSION_MINOR > (minor)) || \
-	(GKRELLM_VERSION_MAJOR == (major) && GKRELLM_VERSION_MINOR == (minor) && \
-	GKRELLM_VERSION_REV >= (rev)))
 
 #define	GKRELLM_DIR				".gkrellm2"
 #define	GKRELLM_USER_CONFIG		".gkrellm2/user-config"
@@ -262,8 +252,8 @@ typedef struct
 #define DF_LOCAL_PIXMAPS		0x4
 #define	DF_OVERLAY_PIXMAPS		0x8
 #define	DF_TEXT_OVERLAPS		0x10
-#define	DF_SCROLL_TEXT_DIVERTED	0x20
-#define	DF_SCROLL_TEXT_CENTER	0x40
+#define	DF_TEXT_CENTER			0x20
+#define	DF_SCROLL_TEXT_DIVERTED	0x40
 #define	DF_SCROLL_TEXT_H_LOOP	0x80
 #define	DF_SCROLL_TEXT_V_LOOP	0x100
 #define	DF_TEXT_USE_MARKUP		0x200
@@ -527,14 +517,6 @@ typedef struct
 	GkrellmPanel;
 
 
-typedef struct
-	{
-	void		(*func)();
-	gpointer	data;
-	}
-	GkrellmCallback;
-
-
 #define CHART_WIDTH_MAX	1600
 #define CHART_WIDTH_MIN	25
 
@@ -1082,5 +1064,4 @@ typedef struct _GkrellmMonitor
 
 #include "gkrellm-public-proto.h"
 
-#endif // GKRELLM_H
-
+#endif
\ No newline at end of file
